summary refs log tree commit diff stats
diff options
context:
space:
mode:
-rw-r--r--ranger/core/actions.py3
1 files changed, 2 insertions, 1 deletions
diff --git a/ranger/core/actions.py b/ranger/core/actions.py
index 5f8f6c53..e875aca3 100644
--- a/ranger/core/actions.py
+++ b/ranger/core/actions.py
@@ -64,7 +64,7 @@ class Actions(  # pylint: disable=too-many-instance-attributes,too-many-public-m
     def reset(self):
         """:reset
 
         Reset the filemanager, clearing the directory buffer.
         """
         old_path = self.thisdir.path
         self.previews = {}
@@ -73,6 +73,7 @@ class Actions(  # pylint: disable=too-many-instance-attributes,too-many-public-m
         self.change_mode('normal')
         if self.metadata:
             self.metadata.reset()
+        self.rifle.reload_config()
 
     def change_mode(self, mode=None):
         """:change_mode <mode>
@@ -64,7 +64,7 @@ class Actions(  # pylint: disable=too-many-instance-attributes,too-many-public-m
         """:reset
 
-        Reset the filemanager, clearing the directory buffer.
+        Reset the filemanager, clearing the directory buffer, reload rifle config
         """
         old_path = self.thisdir.path